Method: CodeBuildNotifier::ProjectSummary#update

Defined in:
lib/codebuild-notifier/project_summary.rb

#update {|updates| ... } ⇒ Object

Creates entries in a partition key with hardcoded primary key. Within the partition key, there is one record for each github repo. The ‘projects’ field in that record is a Map data type, keyed off project code, containing the status of the last build for that code.

Yields:

  • (updates)


26
27
28
29
30
31
32
# File 'lib/codebuild-notifier/project_summary.rb', line 26

def update
  return unless whitelisted_branch?

  updates = project_summary_entry
  yield updates if block_given?
  update_item(updates)
end